#!/usr/bin/env node
'use strict';

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

require('colors');

var _shortenGitCmds = require('./shorten-git-cmds');

var _shortenGitCmds2 = _interopRequireDefault(_shortenGitCmds);

var _configNpmInChina = require('./config-npm-in-China');

var _configNpmInChina2 = _interopRequireDefault(_configNpmInChina);

var _configNodeInChina = require('./config-node-in-China');

var _configNodeInChina2 = _interopRequireDefault(_configNodeInChina);

var _configYarnInChina = require('./config-yarn-in-China');

var _configYarnInChina2 = _interopRequireDefault(_configYarnInChina);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var COMMANDS = [{
    name: 'shorten-git-cmd',
    description: 'Shorten git command (e.g. "git commit -m" => "git cm"; "git commit --amend" => "git ca")',
    action: _shortenGitCmds2.default
}, {
    name: 'config-node',
    description: 'Config node usage in China',
    action: _configNodeInChina2.default
}, {
    name: 'config-npm',
    description: 'Config npm usage in China',
    action: _configNpmInChina2.default
}, {
    name: 'config-yarn',
    description: 'Config yarn usage in China',
    action: _configYarnInChina2.default
}].map(function (cmd) {
    var action = cmd.action;
    cmd.action = function () {
        return action().catch(function (err) {
            console.log(err);
            return Promise.reject(err);
        });
    };
    return cmd;
});

function onError(err) {
    console.error('# ERROR: #'.red);
    console.log((err.stack || err).toString().red);
    process.exit(1);
}

function executeAllCmds() {
    return (0, _utils.sequencePromises)(COMMANDS.map(function (cmd) {
        return function () {
            return cmd.action();
        };
    })).catch(onError);
}

COMMANDS.forEach(function (cmd) {
    _commander2.default.command(cmd.name).description(cmd.description).action(function () {
        return cmd.action().catch(onError);
    });
});

_commander2.default.command('*').action(executeAllCmds);

_commander2.default.parse(process.argv);

if (!_commander2.default.args.length) {
    executeAllCmds();
}