'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = shortenGitCmds;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var GIT_SHORT_COMMANDS = {
    co: 'checkout',
    ca: 'commit --amend',
    cm: 'commit -m',
    a: 'add -A',
    st: 'status',
    br: 'branch',
    p: 'pull --ff-only'
};

function shortenGitCmds() {
    var shortCmdKeys = _lodash2.default.keys(GIT_SHORT_COMMANDS);
    var ensureAllShortCmdsUnset = function ensureAllShortCmdsUnset() {
        return Promise.all(shortCmdKeys.map(function (shortCmd) {
            return (0, _utils.negativePromise)((0, _utils.execCmd)('git config alias.' + shortCmd));
        }));
    };

    return (0, _utils.execCmd)('git --version') //ensureAllShortCmdsUnset()
    .then(function () {
        console.log('# 配置 git: #');
        return (0, _utils.sequencePromises)(_lodash2.default.map(GIT_SHORT_COMMANDS, function (longCmd, shortCmd) {
            return function () {
                return (0, _utils.execCmd)('git config --global alias.' + shortCmd + ' "' + longCmd + '"').then(function () {
                    console.log('  \u5DF2\u8BBE\u7F6EGit\u77ED\u547D\u4EE4: ' + shortCmd + ' = ' + longCmd);
                });
            };
        }));
    }, function () {
        console.log('# 配置 git: # 未安装, 跳过.');
    });
}